﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Themes;
using System.ComponentModel;

namespace ThemeManagerSelector
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {

        public MainWindow()
        {
            InitializeComponent();
            this.xamCombo.SelectedItemChanged += XamCombo_SelectedItemChanged;

            xamCombo.ItemsSource = ThemesData.GetThemesList();
            xamCombo.DisplayMemberPath = "ThemeName";    
        }

        private void XamCombo_SelectedItemChanged(object sender, RoutedPropertyChangedEventArgs<object> e)
        {
            ThemeManager.ApplicationTheme =  new MetroDarkTheme();
            
            var theme = (ThemeItem)xamCombo.SelectedItem;
            xamCombo.Background = theme.ThemeID.Equals("MetroDark") ? new SolidColorBrush(Colors.Black) : new SolidColorBrush(Colors.White);
            SetTheme(xamCombo, theme);
        }

        private void SetTheme(FrameworkElement element, ThemeItem theme)
        {
            // Apply a theme to a FrameworkElement using the ThemeManager SetTheme method
            ThemeManager.SetTheme(element, theme.Theme);
        }
        
        public static class ThemesData 
        {
            public static IEnumerable<ThemeItem> ThemeItems { get; set; }

            public static IEnumerable<ThemeItem> GetThemesList()
            {
                    return new List<ThemeItem>
                {
                    new ThemeItem("IG", "IG", new IgTheme()),
                    new ThemeItem("Metro", "Metro", new MetroTheme()),
                    new ThemeItem("MetroDark", "MetroDark", new MetroDarkTheme()),
                    new ThemeItem("Office2010", "Office2010", new Office2010BlueTheme()),
                    new ThemeItem("Office2013", "Office2013", new Office2013Theme())

                    //etc.
                };
            }
        }

        public class ThemeItem : ObservableModel
        {
            public string ThemeID { get; set; }
            public string ThemeName { get; set; }
            public BuiltInThemeBase Theme { get; set; }


            public ThemeItem(string themeID, string localizableThemeName, BuiltInThemeBase theme)
            {
                ThemeID = themeID;
                ThemeName = localizableThemeName;
                Theme = theme;
            }
        }

        public class ObservableModel : INotifyPropertyChanged
        {
            public event PropertyChangedEventHandler PropertyChanged;
            protected void OnPropertyChanged(object sender, PropertyChangedEventArgs e)
            {
                PropertyChangedEventHandler handler = this.PropertyChanged;
                if (handler != null)
                    handler(sender, e);
            }
            protected void OnPropertyChanged(string propertyName)
            {
                OnPropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

    }
    
}




